%bcond_with bootstrap

Name:              httpcomponents-client
Summary:           HTTP agent implementation based on httpcomponents HttpCore
Version:           4.5.14
Release:           %mkrel 1
Group:             Development/Java
License:           ASL 2.0
URL:               https://hc.apache.org/
Source0:           https://repo1.maven.org/maven2/org/apache/httpcomponents/httpcomponents-client/%{version}/httpcomponents-client-%{version}-source-release.zip
BuildArch:         noarch
#ExclusiveArch:     %%{java_arches} noarch

Patch1:            0001-Use-system-copy-of-effective_tld_names.dat.patch
Patch2:            0002-Port-to-mockito-2.patch
Patch3:            0003-Port-to-Mockito-5.patch

%if %{with bootstrap}
BuildRequires:     javapackages-bootstrap
%else
BuildRequires:     maven-local
BuildRequires:     mvn(commons-codec:commons-codec)
BuildRequires:     mvn(commons-logging:commons-logging)
BuildRequires:     mvn(junit:junit)
BuildRequires:     mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:     mvn(org.apache.httpcomponents:httpcomponents-parent:pom:)
BuildRequires:     mvn(org.apache.httpcomponents:httpcore)
BuildRequires:     mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:     mvn(org.mockito:mockito-core)
%endif

%if %{without bootstrap}
BuildRequires:     publicsuffix-list
%endif
Requires:          publicsuffix-list

%description
HttpClient is a HTTP/1.1 compliant HTTP agent implementation based on
httpcomponents HttpCore. It also provides reusable components for
client-side authentication, HTTP state management, and HTTP connection
management. HttpComponents Client is a successor of and replacement
for Commons HttpClient 3.x. Users of Commons HttpClient are strongly
encouraged to upgrade.

%{?javadoc_package}

%prep
%setup -q -n %{name}-%{version}
%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1

%mvn_package :::tests: __noinstall

# Change scope of commons-logging to provided
%pom_change_dep :commons-logging :::provided httpclient

# Remove optional build deps not available in Fedora
%pom_disable_module httpclient-osgi
%pom_disable_module httpclient-win
%pom_disable_module fluent-hc
%pom_disable_module httpmime
%pom_disable_module httpclient-cache
%pom_remove_plugin :docbkx-maven-plugin
%pom_remove_plugin :clirr-maven-plugin
%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :animal-sniffer-maven-plugin

# Fails due to strict crypto policy - uses DSA in test data
rm httpclient/src/test/java/org/apache/http/conn/ssl/TestSSLSocketFactory.java

%pom_remove_plugin :download-maven-plugin httpclient

%pom_xpath_inject "pom:archive" "
    <manifestFile>\${project.build.outputDirectory}/META-INF/MANIFEST.MF</manifestFile>"

%pom_xpath_inject pom:build/pom:plugins "
    <plugin>
      <groupId>org.apache.felix</groupId>
      <artifactId>maven-bundle-plugin</artifactId>
      <executions>
        <execution>
          <id>bundle-manifest</id>
          <phase>process-classes</phase>
          <goals>
            <goal>manifest</goal>
          </goals>
        </execution>
      </executions>
    </plugin>"

%pom_xpath_inject pom:build "
<pluginManagement>
  <plugins>
    <plugin>
      <groupId>org.apache.felix</groupId>
      <artifactId>maven-bundle-plugin</artifactId>
      <configuration>
        <instructions>
          <Export-Package>org.apache.http.*,!org.apache.http.param</Export-Package>
          <Private-Package></Private-Package>
          <_nouses>true</_nouses>
          <Import-Package>!org.apache.avalon.framework.logger,!org.apache.log,!org.apache.log4j,*</Import-Package>
        </instructions>
        <excludeDependencies>true</excludeDependencies>
      </configuration>
    </plugin>
  </plugins>
</pluginManagement>
" httpclient

# requires network
rm httpclient/src/test/java/org/apache/http/client/config/TestRequestConfig.java

%build
%mvn_file ":{*}" httpcomponents/@1

%mvn_build -- -Dmaven.compiler.release=8

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt NOTICE.txt
%doc README.txt RELEASE_NOTES.txt




%changelog
* Thu May 23 2024 ns80 <ns80> 4.5.14-1.mga10
+ Revision: 2066696
- new version 4.5.14 for java 21

* Mon Jul 25 2022 neoclust <neoclust> 4.5.13-5.mga9
+ Revision: 1871028
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 4.5.13-4.mga9
+ Revision: 1870268
- Fix BR for bootstrap
- Enable bootstrap
- New version 4.5.13
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Jan 02 2021 neoclust <neoclust> 4.5.10-3.mga8
+ Revision: 1668068
- Obsolete jakarta-commons-httpclient

* Sun Dec 27 2020 neoclust <neoclust> 4.5.10-2.mga8
+ Revision: 1664179
- Add P2 to fix CVE-2020-13956 (mga#27389)

* Mon Aug 24 2020 neoclust <neoclust> 4.5.10-1.mga8
+ Revision: 1618569
- New version 4.5.10

* Sun Feb 16 2020 umeabot <umeabot> 4.5.7-3.mga8
+ Revision: 1536141
- Mageia 8 Mass Rebuild

* Tue Oct 15 2019 daviddavid <daviddavid> 4.5.7-2.mga8
+ Revision: 1453338
- Disable memcached and ehcache support

* Wed Aug 21 2019 daviddavid <daviddavid> 4.5.7-1.mga8
+ Revision: 1430783
- Update to upstream version 4.5.7
- Add a patch to allow building with mockito 2
- Don't package tests jars, the tests jars have the same OSGi metadata as the
  main jars, which can cause tycho to resolve the wrong one when building
  eclipse plugins

* Mon Dec 10 2018 daviddavid <daviddavid> 4.5.5-1.mga7
+ Revision: 1339752
- new version: 4.5.5 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 4.5.2-5.mga7
+ Revision: 1261194
- Mageia 7 Mass Rebuild

* Mon May 15 2017 neoclust <neoclust> 4.5.2-4.mga6
+ Revision: 1101358
- Fix build with httpcomponents-core-4.4.5

* Fri Apr 29 2016 daviddavid <daviddavid> 4.5.2-2.mga6
+ Revision: 1007680
- Make the fluent API into a bundle

* Thu Mar 03 2016 neoclust <neoclust> 4.5.2-1.mga6
+ Revision: 984467
- Second rebuild of the java stack
+ daviddavid <daviddavid>
- Update to upstream version 4.5.2
- Enable the fluent API module

* Tue Feb 23 2016 neoclust <neoclust> 4.5.1-2.mga6
+ Revision: 976377
- First rebuild of the java stack
- sync package httpcomponents-client with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild
+ daviddavid <daviddavid>
- sync with fc24 (update to 4.5.1)
- fix owner of maven-poms dir and java dir

* Fri Oct 02 2015 daviddavid <daviddavid> 4.3.6-1.mga6
+ Revision: 885634
- new version: 4.3.6 (fixes CVE-2015-5262) (mga#16870)
- fix Group

* Thu Dec 25 2014 pterjan <pterjan> 4.3.5-5.mga5
+ Revision: 805563
- Clean rebuild
- Sync with Fedora 21
- Restore
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 4.3.5-3.mga5
+ Revision: 748612
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Wed Aug 20 2014 luigiwalser <luigiwalser> 4.3.5-1.mga5
+ Revision: 666043
- 4.3.5 (fixes CVE-2014-3577)
- fix BR on httpcomponents-project

* Sun Jun 29 2014 dmorgan <dmorgan> 4.3.4-1.mga5
+ Revision: 641203
- New version

* Sat Dec 21 2013 dmorgan <dmorgan> 4.3-1.mga4
+ Revision: 559540
- Build with maven-local
- New version
- Build with xmvn
- New version
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 4.2.2-2.mga3
+ Revision: 353347
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Dec 04 2012 dmorgan <dmorgan> 4.2.2-1.mga3
+ Revision: 326393
- New version

* Wed Sep 12 2012 dmorgan <dmorgan> 4.2.1-1.mga3
+ Revision: 292977
- New version

* Sat Sep 08 2012 dmorgan <dmorgan> 4.1.3-3.mga3
+ Revision: 290514
- Do not export org.apache.http.param in osgi.

* Mon Jul 16 2012 dmorgan <dmorgan> 4.1.3-2.mga3
+ Revision: 271252
- Do not export * but only org.apache.http.* .
- Do not generate uses clauses in the manifest.

* Mon Jul 09 2012 dmorgan <dmorgan> 4.1.3-1.mga3
+ Revision: 269085
- New version 4.1.3

* Sat Dec 10 2011 dmorgan <dmorgan> 4.1.2-1.mga2
+ Revision: 179896
- New version 4.1.2
- Fix for RH Bz#718830. Add instructions so as to not
  Import-Package optional dependencies.

* Tue Jul 19 2011 dmorgan <dmorgan> 4.1.1-3.mga2
+ Revision: 126097
- Add BR/R apache-commons-codec, since httpcomponents-client's
  MANIFEST.MF has an Import-Package: org.apache.commons.codec
  header.

* Thu Apr 28 2011 dmorgan <dmorgan> 4.1.1-2.mga1
+ Revision: 92452
- Rebuild after bootstrapping
- imported package httpcomponents-client


* Tue Mar 29 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 4.1.1-1
- New upstream bugfix version (4.1.1)

* Tue Mar 15 2011 Severin Gehwolf <sgehwolf@redhat.com> 4.1-6
- Explicitly set PrivatePackage to the empty set, so as to
  export all packages.

* Thu Mar 10 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-5
- OSGi export more packages.

* Fri Feb 25 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-4
- Build httpmime module.

* Fri Feb 18 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-3
- Don't use basename as an identifier.

* Fri Feb 18 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-2
- OSGify properly.
- Install into %%{_javadir}/%%{basename}.

* Thu Feb 17 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-1
- Update to latest upstream version.

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 4.0.3-2
- Added license to javadoc subpackage

* Mon Dec 20 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 4.0.3-1
- Initial version
